/*
 * plot.h --
 *
 * Contains definitions for things that are exported by the
 * plot module.
 *
 *     ********************************************************************* 
 *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
 *     * Permission to use, copy, modify, and distribute this              * 
 *     * software and its documentation for any purpose and without        * 
 *     * fee is hereby granted, provided that the above copyright          * 
 *     * notice appear in all copies.  The University of California        * 
 *     * makes no representations about the suitability of this            * 
 *     * software for any purpose.  It is provided "as is" without         * 
 *     * express or implied warranty.  Export of this software outside     * 
 *     * of the United States of America may require an export license.    * 
 *     *********************************************************************
 *
 * rcsid $Header: /ufs/repository/magic/plot/plot.h,v 1.4 2001/01/12 22:13:09 jsolomon Exp $
 */

#ifndef _PLOT_H
#define _PLOT_H

#include "utils/magic.h"

/* Technology-file reading procedures: */

extern int PlotTechInit();
extern bool PlotTechLine();
extern void PlotTechFinal();

/* Top-level plot procedures: */

#ifdef GREMLIN
extern void PlotGremlin();
#endif
#ifdef VERSATEC
extern void PlotVersatec();
#endif
extern void PlotPS();
extern void PlotPNM();
extern void PlotSetParam();
extern void PlotPrintParams();

#endif /* _PLOT_H */
